FreezeBuilder

Trait FreezeBuilder 

pub trait FreezeBuilder {
    type Octets;

    // Required method
    fn freeze(self) -> Self::Octets;
}
An octets builder that can be frozen into a immutable octets sequence.

Required Associated Types

type Octets

The type of octets sequence to builder will be frozen into.

Required Methods

fn freeze(self) -> Self::Octets

Converts the octets builder into an immutable octets sequence.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl FreezeBuilder for BytesMut

Available on crate feature bytes only.
Source

type Octets = Bytes

Source

fn freeze(self) -> Self::Octets

Source

impl FreezeBuilder for Vec<u8>

Available on crate feature std only.
Source

type Octets = Vec<u8>

Source

fn freeze(self) -> Self::Octets

Source

impl<'a> FreezeBuilder for Cow<'a, [u8]>

Available on crate feature std only.
Source

type Octets = Cow<'a, [u8]>

Source

fn freeze(self) -> Self::Octets

Source

impl<A: Array<Item = u8>> FreezeBuilder for SmallVec<A>

Available on crate feature smallvec only.
Source

type Octets = SmallVec<A>

Source

fn freeze(self) -> Self::Octets

Implementors

Source

impl<const N: usize> FreezeBuilder for Array<N>