IntoBuilder

Trait IntoBuilder 

pub trait IntoBuilder {
    type Builder: OctetsBuilder;

    // Required method
    fn into_builder(self) -> Self::Builder;
}
An octets type that can be converted into an octets builder.

Required Associated Types

type Builder: OctetsBuilder

The type of octets builder this octets type can be converted into.

Required Methods

fn into_builder(self) -> Self::Builder

Converts an octets value into an octets builder.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl IntoBuilder for Bytes

Available on crate feature bytes only.
Source

impl IntoBuilder for Vec<u8>

Available on crate feature std only.
Source

impl<'a> IntoBuilder for &'a [u8]

Available on crate feature std only.
Source

impl<'a> IntoBuilder for Cow<'a, [u8]>

Available on crate feature std only.
Source

type Builder = Cow<'a, [u8]>

Source

fn into_builder(self) -> Self::Builder

Source

impl<A: Array<Item = u8>> IntoBuilder for SmallVec<A>

Available on crate feature smallvec only.

Implementors

Source

impl<const N: usize> IntoBuilder for Array<N>